# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/legacy/other/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66x/legacy/other/query.proto\x12\x08\x66x.other\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\"\x11\n\x0fGasPriceRequest\"\x88\x01\n\x10GasPriceResponse\x12t\n\ngas_prices\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xc8\xde\x1f\x00\xf2\xde\x1f\x11yaml:\"gas_prices\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins2\xc9\x01\n\x05Query\x12`\n\nFxGasPrice\x12\x19.fx.other.GasPriceRequest\x1a\x1a.fx.other.GasPriceResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/fx/other/gas_price\x12^\n\x08GasPrice\x12\x19.fx.other.GasPriceRequest\x1a\x1a.fx.other.GasPriceResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/other/v1/gas_priceB=Z;github.com/functionx/fx-core/server/grpc/gasprice/legacy/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.legacy.other.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/functionx/fx-core/server/grpc/gasprice/legacy/v1'
  _GASPRICERESPONSE.fields_by_name['gas_prices']._options = None
  _GASPRICERESPONSE.fields_by_name['gas_prices']._serialized_options = b'\310\336\037\000\362\336\037\021yaml:\"gas_prices\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERY.methods_by_name['FxGasPrice']._options = None
  _QUERY.methods_by_name['FxGasPrice']._serialized_options = b'\202\323\344\223\002\025\022\023/fx/other/gas_price'
  _QUERY.methods_by_name['GasPrice']._options = None
  _QUERY.methods_by_name['GasPrice']._serialized_options = b'\202\323\344\223\002\025\022\023/other/v1/gas_price'
  _globals['_GASPRICEREQUEST']._serialized_start=125
  _globals['_GASPRICEREQUEST']._serialized_end=142
  _globals['_GASPRICERESPONSE']._serialized_start=145
  _globals['_GASPRICERESPONSE']._serialized_end=281
  _globals['_QUERY']._serialized_start=284
  _globals['_QUERY']._serialized_end=485
# @@protoc_insertion_point(module_scope)
