# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/crosschain/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x66x/crosschain/v1/types.proto\x12\x18\x66x.gravity.crosschain.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"!\n\x0eProposalOracle\x12\x0f\n\x07oracles\x18\x01 \x03(\t\"\xf3\x01\n\x06Oracle\x12\x16\n\x0eoracle_address\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridger_address\x18\x02 \x01(\t\x12\x18\n\x10\x65xternal_address\x18\x03 \x01(\t\x12G\n\x0f\x64\x65legate_amount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x14\n\x0cstart_height\x18\x05 \x01(\x03\x12\x0e\n\x06online\x18\x06 \x01(\x08\x12\x1a\n\x12\x64\x65legate_validator\x18\x07 \x01(\t\x12\x13\n\x0bslash_times\x18\x08 \x01(\x03\":\n\x0f\x42ridgeValidator\x12\r\n\x05power\x18\x01 \x01(\x04\x12\x18\n\x10\x65xternal_address\x18\x02 \x01(\t\"l\n\tOracleSet\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12@\n\x07members\x18\x02 \x03(\x0b\x32).fx.gravity.crosschain.v1.BridgeValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x04\"N\n\x17LastObservedBlockHeight\x12\x1d\n\x15\x65xternal_block_height\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\"@\n\x0b\x42ridgeToken\x12\r\n\x05token\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x13\n\x0b\x63hannel_ibc\x18\x03 \x01(\t\"c\n\x0b\x41ttestation\x12\x10\n\x08observed\x18\x01 \x01(\x08\x12\r\n\x05votes\x18\x02 \x03(\t\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12#\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\xbc\x01\n\x0fOutgoingTxBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x02 \x01(\x04\x12\x42\n\x0ctransactions\x18\x03 \x03(\x0b\x32,.fx.gravity.crosschain.v1.OutgoingTransferTx\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\r\n\x05\x62lock\x18\x05 \x01(\x04\x12\x12\n\nfeeReceive\x18\x06 \x01(\t\"\xba\x01\n\x12OutgoingTransferTx\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65st_address\x18\x03 \x01(\t\x12\x39\n\x05token\x18\x04 \x01(\x0b\x32$.fx.gravity.crosschain.v1.ERC20TokenB\x04\xc8\xde\x1f\x00\x12\x37\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32$.fx.gravity.crosschain.v1.ERC20TokenB\x04\xc8\xde\x1f\x00\"^\n\nERC20Token\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"\x14\n\x05IDSet\x12\x0b\n\x03ids\x18\x01 \x03(\x04\"\xc0\x01\n\tBatchFees\x12\x16\n\x0etoken_contract\x18\x01 \x01(\t\x12\x42\n\ntotal_fees\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x11\n\ttotal_txs\x18\x03 \x01(\x04\x12\x44\n\x0ctotal_amount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"f\n\x0bMinBatchFee\x12\x16\n\x0etoken_contract\x18\x01 \x01(\t\x12?\n\x07\x62\x61seFee\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"\xd6\x03\n\x06Params\x12\x12\n\ngravity_id\x18\x01 \x01(\t\x12\x1a\n\x12\x61verage_block_time\x18\x02 \x01(\x04\x12\x1e\n\x16\x65xternal_batch_timeout\x18\x03 \x01(\x04\x12#\n\x1b\x61verage_external_block_time\x18\x04 \x01(\x04\x12\x15\n\rsigned_window\x18\x05 \x01(\x04\x12\x46\n\x0eslash_fraction\x18\x06 \x01(\x0c\x42.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12^\n&oracle_set_update_power_change_percent\x18\x07 \x01(\x0c\x42.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12#\n\x1bibc_transfer_timeout_height\x18\x08 \x01(\x04\x12\x15\n\x07oracles\x18\t \x03(\tB\x04\xc8\xde\x1f\x01\x12;\n\x12\x64\x65legate_threshold\x18\n \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x19\n\x11\x64\x65legate_multiple\x18\x0b \x01(\x03:\x04\x80\xdc \x00\"\x96\x01\n\x1cInitCrossChainParamsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x30\n\x06params\x18\x03 \x01(\x0b\x32 .fx.gravity.crosschain.v1.Params\x12\x12\n\nchain_name\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"s\n\x1aUpdateChainOraclesProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07oracles\x18\x03 \x03(\t\x12\x12\n\nchain_name\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00*\xa9\x01\n\tClaimType\x12\x1a\n\x16\x43LAIM_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LAIM_TYPE_SEND_TO_FX\x10\x01\x12\x1f\n\x1b\x43LAIM_TYPE_SEND_TO_EXTERNAL\x10\x02\x12\x1b\n\x17\x43LAIM_TYPE_BRIDGE_TOKEN\x10\x03\x12!\n\x1d\x43LAIM_TYPE_ORACLE_SET_UPDATED\x10\x04\x1a\x04\x88\xa3\x1e\x00\x42\x31Z/github.com/functionx/fx-core/x/crosschain/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.crosschain.v1.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/functionx/fx-core/x/crosschain/types'
  _CLAIMTYPE._options = None
  _CLAIMTYPE._serialized_options = b'\210\243\036\000'
  _ORACLE.fields_by_name['delegate_amount']._options = None
  _ORACLE.fields_by_name['delegate_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _ORACLESET.fields_by_name['members']._options = None
  _ORACLESET.fields_by_name['members']._serialized_options = b'\310\336\037\000'
  _OUTGOINGTRANSFERTX.fields_by_name['token']._options = None
  _OUTGOINGTRANSFERTX.fields_by_name['token']._serialized_options = b'\310\336\037\000'
  _OUTGOINGTRANSFERTX.fields_by_name['fee']._options = None
  _OUTGOINGTRANSFERTX.fields_by_name['fee']._serialized_options = b'\310\336\037\000'
  _ERC20TOKEN.fields_by_name['amount']._options = None
  _ERC20TOKEN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BATCHFEES.fields_by_name['total_fees']._options = None
  _BATCHFEES.fields_by_name['total_fees']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BATCHFEES.fields_by_name['total_amount']._options = None
  _BATCHFEES.fields_by_name['total_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MINBATCHFEE.fields_by_name['baseFee']._options = None
  _MINBATCHFEE.fields_by_name['baseFee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _PARAMS.fields_by_name['slash_fraction']._options = None
  _PARAMS.fields_by_name['slash_fraction']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PARAMS.fields_by_name['oracle_set_update_power_change_percent']._options = None
  _PARAMS.fields_by_name['oracle_set_update_power_change_percent']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PARAMS.fields_by_name['oracles']._options = None
  _PARAMS.fields_by_name['oracles']._serialized_options = b'\310\336\037\001'
  _PARAMS.fields_by_name['delegate_threshold']._options = None
  _PARAMS.fields_by_name['delegate_threshold']._serialized_options = b'\310\336\037\000'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\200\334 \000'
  _INITCROSSCHAINPARAMSPROPOSAL._options = None
  _INITCROSSCHAINPARAMSPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _UPDATECHAINORACLESPROPOSAL._options = None
  _UPDATECHAINORACLESPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _globals['_CLAIMTYPE']._serialized_start=2378
  _globals['_CLAIMTYPE']._serialized_end=2547
  _globals['_PROPOSALORACLE']._serialized_start=139
  _globals['_PROPOSALORACLE']._serialized_end=172
  _globals['_ORACLE']._serialized_start=175
  _globals['_ORACLE']._serialized_end=418
  _globals['_BRIDGEVALIDATOR']._serialized_start=420
  _globals['_BRIDGEVALIDATOR']._serialized_end=478
  _globals['_ORACLESET']._serialized_start=480
  _globals['_ORACLESET']._serialized_end=588
  _globals['_LASTOBSERVEDBLOCKHEIGHT']._serialized_start=590
  _globals['_LASTOBSERVEDBLOCKHEIGHT']._serialized_end=668
  _globals['_BRIDGETOKEN']._serialized_start=670
  _globals['_BRIDGETOKEN']._serialized_end=734
  _globals['_ATTESTATION']._serialized_start=736
  _globals['_ATTESTATION']._serialized_end=835
  _globals['_OUTGOINGTXBATCH']._serialized_start=838
  _globals['_OUTGOINGTXBATCH']._serialized_end=1026
  _globals['_OUTGOINGTRANSFERTX']._serialized_start=1029
  _globals['_OUTGOINGTRANSFERTX']._serialized_end=1215
  _globals['_ERC20TOKEN']._serialized_start=1217
  _globals['_ERC20TOKEN']._serialized_end=1311
  _globals['_IDSET']._serialized_start=1313
  _globals['_IDSET']._serialized_end=1333
  _globals['_BATCHFEES']._serialized_start=1336
  _globals['_BATCHFEES']._serialized_end=1528
  _globals['_MINBATCHFEE']._serialized_start=1530
  _globals['_MINBATCHFEE']._serialized_end=1632
  _globals['_PARAMS']._serialized_start=1635
  _globals['_PARAMS']._serialized_end=2105
  _globals['_INITCROSSCHAINPARAMSPROPOSAL']._serialized_start=2108
  _globals['_INITCROSSCHAINPARAMSPROPOSAL']._serialized_end=2258
  _globals['_UPDATECHAINORACLESPROPOSAL']._serialized_start=2260
  _globals['_UPDATECHAINORACLESPROPOSAL']._serialized_end=2375
# @@protoc_insertion_point(module_scope)
