# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/migrate/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.fx.migrate.v1 import migrate_pb2 as fx_dot_migrate_dot_v1_dot_migrate__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66x/migrate/v1/genesis.proto\x12\rfx.migrate.v1\x1a\x1b\x66x/migrate/v1/migrate.proto\x1a\x14gogoproto/gogo.proto\"K\n\x0cGenesisState\x12;\n\x0fmigrate_records\x18\x01 \x03(\x0b\x32\x1c.fx.migrate.v1.MigrateRecordB\x04\xc8\xde\x1f\x00\x42.Z,github.com/functionx/fx-core/x/migrate/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.migrate.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/migrate/types'
  _GENESISSTATE.fields_by_name['migrate_records']._options = None
  _GENESISSTATE.fields_by_name['migrate_records']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=97
  _globals['_GENESISSTATE']._serialized_end=172
# @@protoc_insertion_point(module_scope)
