# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/types/v1/web3.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65thermint/types/v1/web3.proto\x12\x12\x65thermint.types.v1\x1a\x14gogoproto/gogo.proto\"\xcc\x01\n\x16\x45xtensionOptionsWeb3Tx\x12O\n\x13typed_data_chain_id\x18\x01 \x01(\x04\x42\x32\xe2\xde\x1f\x10TypedDataChainID\xea\xde\x1f\x1atypedDataChainID,omitempty\x12)\n\tfee_payer\x18\x02 \x01(\tB\x16\xea\xde\x1f\x12\x66\x65\x65Payer,omitempty\x12\x30\n\rfee_payer_sig\x18\x03 \x01(\x0c\x42\x19\xea\xde\x1f\x15\x66\x65\x65PayerSig,omitempty:\x04\x88\xa0\x1f\x00\x42\"Z github.com/evmos/ethermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.types.v1.web3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z github.com/evmos/ethermint/types'
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['typed_data_chain_id']._options = None
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['typed_data_chain_id']._serialized_options = b'\342\336\037\020TypedDataChainID\352\336\037\032typedDataChainID,omitempty'
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer']._options = None
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer']._serialized_options = b'\352\336\037\022feePayer,omitempty'
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer_sig']._options = None
  _EXTENSIONOPTIONSWEB3TX.fields_by_name['fee_payer_sig']._serialized_options = b'\352\336\037\025feePayerSig,omitempty'
  _EXTENSIONOPTIONSWEB3TX._options = None
  _EXTENSIONOPTIONSWEB3TX._serialized_options = b'\210\240\037\000'
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_start=76
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_end=280
# @@protoc_insertion_point(module_scope)
