# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/legacy/gravity/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.fx.legacy.gravity.v1 import types_pb2 as fx_dot_legacy_dot_gravity_dot_v1_dot_types__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x66x/legacy/gravity/v1/tx.proto\x12\rfx.gravity.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a fx/legacy/gravity/v1/types.proto\x1a\x14gogoproto/gogo.proto\"_\n\x10MsgValsetConfirm\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t\"\x1a\n\x18MsgValsetConfirmResponse\"\x96\x01\n\x0cMsgSendToEth\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x65th_dest\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x33\n\nbridge_fee\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x16\n\x14MsgSendToEthResponse\"\xcb\x01\n\x0fMsgRequestBatch\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x43\n\x0bminimum_fee\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x12\n\nfeeReceive\x18\x04 \x01(\t\x12@\n\x08\x62\x61se_fee\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"\x19\n\x17MsgRequestBatchResponse\"u\n\x0fMsgConfirmBatch\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x02 \x01(\t\x12\x12\n\neth_signer\x18\x03 \x01(\t\x12\x14\n\x0corchestrator\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x05 \x01(\t\"\x19\n\x17MsgConfirmBatchResponse\"\xe7\x01\n\x0fMsgDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x03 \x01(\t\x12>\n\x06\x61mount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x12\n\neth_sender\x18\x05 \x01(\t\x12\x13\n\x0b\x66x_receiver\x18\x06 \x01(\t\x12\x12\n\ntarget_ibc\x18\x07 \x01(\t\x12\x14\n\x0corchestrator\x18\x08 \x01(\t\"\x19\n\x17MsgDepositClaimResponse\"\x80\x01\n\x10MsgWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\x14\n\x0corchestrator\x18\x05 \x01(\t\"\x1a\n\x18MsgWithdrawClaimResponse\"<\n\x12MsgCancelSendToEth\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\"\x1c\n\x1aMsgCancelSendToEthResponse\"\x9f\x01\n\x15MsgValsetUpdatedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x14\n\x0cvalset_nonce\x18\x03 \x01(\x04\x12/\n\x07members\x18\x04 \x03(\x0b\x32\x1e.fx.gravity.v1.BridgeValidator\x12\x14\n\x0corchestrator\x18\x06 \x01(\t\"\x1f\n\x1dMsgValsetUpdatedClaimResponse\"Y\n\x19MsgSetOrchestratorAddress\x12\x11\n\tvalidator\x18\x01 \x01(\t\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\"#\n!MsgSetOrchestratorAddressResponse\"\xa4\x01\n\x19MsgFxOriginatedTokenClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x06 \x01(\x04\x12\x14\n\x0corchestrator\x18\x07 \x01(\t\"#\n!MsgFxOriginatedTokenClaimResponse2\xdc\x05\n\x03Msg\x12Y\n\rValsetConfirm\x12\x1f.fx.gravity.v1.MsgValsetConfirm\x1a\'.fx.gravity.v1.MsgValsetConfirmResponse\x12M\n\tSendToEth\x12\x1b.fx.gravity.v1.MsgSendToEth\x1a#.fx.gravity.v1.MsgSendToEthResponse\x12V\n\x0cRequestBatch\x12\x1e.fx.gravity.v1.MsgRequestBatch\x1a&.fx.gravity.v1.MsgRequestBatchResponse\x12V\n\x0c\x43onfirmBatch\x12\x1e.fx.gravity.v1.MsgConfirmBatch\x1a&.fx.gravity.v1.MsgConfirmBatchResponse\x12V\n\x0c\x44\x65positClaim\x12\x1e.fx.gravity.v1.MsgDepositClaim\x1a&.fx.gravity.v1.MsgDepositClaimResponse\x12Y\n\rWithdrawClaim\x12\x1f.fx.gravity.v1.MsgWithdrawClaim\x1a\'.fx.gravity.v1.MsgWithdrawClaimResponse\x12_\n\x0f\x43\x61ncelSendToEth\x12!.fx.gravity.v1.MsgCancelSendToEth\x1a).fx.gravity.v1.MsgCancelSendToEthResponse\x12g\n\x11ValsetUpdateClaim\x12$.fx.gravity.v1.MsgValsetUpdatedClaim\x1a,.fx.gravity.v1.MsgValsetUpdatedClaimResponseB.Z,github.com/functionx/fx-core/x/gravity/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.legacy.gravity.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/gravity/types'
  _MSGSENDTOETH.fields_by_name['amount']._options = None
  _MSGSENDTOETH.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGSENDTOETH.fields_by_name['bridge_fee']._options = None
  _MSGSENDTOETH.fields_by_name['bridge_fee']._serialized_options = b'\310\336\037\000'
  _MSGREQUESTBATCH.fields_by_name['minimum_fee']._options = None
  _MSGREQUESTBATCH.fields_by_name['minimum_fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGREQUESTBATCH.fields_by_name['base_fee']._options = None
  _MSGREQUESTBATCH.fields_by_name['base_fee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGDEPOSITCLAIM.fields_by_name['amount']._options = None
  _MSGDEPOSITCLAIM.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _globals['_MSGVALSETCONFIRM']._serialized_start=136
  _globals['_MSGVALSETCONFIRM']._serialized_end=231
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_start=233
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_end=259
  _globals['_MSGSENDTOETH']._serialized_start=262
  _globals['_MSGSENDTOETH']._serialized_end=412
  _globals['_MSGSENDTOETHRESPONSE']._serialized_start=414
  _globals['_MSGSENDTOETHRESPONSE']._serialized_end=436
  _globals['_MSGREQUESTBATCH']._serialized_start=439
  _globals['_MSGREQUESTBATCH']._serialized_end=642
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_start=644
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_end=669
  _globals['_MSGCONFIRMBATCH']._serialized_start=671
  _globals['_MSGCONFIRMBATCH']._serialized_end=788
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_start=790
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_end=815
  _globals['_MSGDEPOSITCLAIM']._serialized_start=818
  _globals['_MSGDEPOSITCLAIM']._serialized_end=1049
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_start=1051
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_end=1076
  _globals['_MSGWITHDRAWCLAIM']._serialized_start=1079
  _globals['_MSGWITHDRAWCLAIM']._serialized_end=1207
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_start=1209
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_end=1235
  _globals['_MSGCANCELSENDTOETH']._serialized_start=1237
  _globals['_MSGCANCELSENDTOETH']._serialized_end=1297
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_start=1299
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_end=1327
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_start=1330
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_end=1489
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_start=1491
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_end=1522
  _globals['_MSGSETORCHESTRATORADDRESS']._serialized_start=1524
  _globals['_MSGSETORCHESTRATORADDRESS']._serialized_end=1613
  _globals['_MSGSETORCHESTRATORADDRESSRESPONSE']._serialized_start=1615
  _globals['_MSGSETORCHESTRATORADDRESSRESPONSE']._serialized_end=1650
  _globals['_MSGFXORIGINATEDTOKENCLAIM']._serialized_start=1653
  _globals['_MSGFXORIGINATEDTOKENCLAIM']._serialized_end=1817
  _globals['_MSGFXORIGINATEDTOKENCLAIMRESPONSE']._serialized_start=1819
  _globals['_MSGFXORIGINATEDTOKENCLAIMRESPONSE']._serialized_end=1854
  _globals['_MSG']._serialized_start=1857
  _globals['_MSG']._serialized_end=2589
# @@protoc_insertion_point(module_scope)
