# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/auth/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x66x/auth/v1/query.proto\x12\nfx.auth.v1\x1a\x1cgoogle/api/annotations.proto\"8\n\x15\x43onvertAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\")\n\x16\x43onvertAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t2\x86\x01\n\x05Query\x12}\n\x0e\x43onvertAddress\x12!.fx.auth.v1.ConvertAddressRequest\x1a\".fx.auth.v1.ConvertAddressResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/fx/auth/v1/bech32/{address}B/Z-github.com/functionx/fx-core/server/grpc/authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.auth.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/functionx/fx-core/server/grpc/auth'
  _QUERY.methods_by_name['ConvertAddress']._options = None
  _QUERY.methods_by_name['ConvertAddress']._serialized_options = b'\202\323\344\223\002\036\022\034/fx/auth/v1/bech32/{address}'
  _globals['_CONVERTADDRESSREQUEST']._serialized_start=68
  _globals['_CONVERTADDRESSREQUEST']._serialized_end=124
  _globals['_CONVERTADDRESSRESPONSE']._serialized_start=126
  _globals['_CONVERTADDRESSRESPONSE']._serialized_end=167
  _globals['_QUERY']._serialized_start=170
  _globals['_QUERY']._serialized_end=304
# @@protoc_insertion_point(module_scope)
