# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/funding.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x66x/dex/v1/funding.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\"s\n\x0fPairFundingRate\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x39\n\x0c\x66unding_rate\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x14\n\x0c\x66unding_time\x18\x03 \x01(\x03\"\xe3\x01\n\x07\x46unding\x12\x16\n\x0e\x66unding_period\x18\x01 \x01(\x03\x12\x19\n\x11next_funding_time\x18\x02 \x01(\x03\x12\x15\n\rfunding_times\x18\x03 \x01(\x03\x12\x1d\n\x15max_funding_per_block\x18\x04 \x01(\x03\x12#\n\x15\x63rypto_funding_period\x18\x05 \x01(\x03\x42\x04\xc8\xde\x1f\x01\x12&\n\x18\x63rypto_next_funding_time\x18\x06 \x01(\x03\x42\x04\xc8\xde\x1f\x01\x12\"\n\x14\x63rypto_funding_times\x18\x07 \x01(\x03\x42\x04\xc8\xde\x1f\x01\"\x8e\x01\n\x0b\x46undingTime\x12\x13\n\x0bsummer_time\x18\x01 \x01(\x03\x12\x13\n\x0bwinter_time\x18\x02 \x01(\x03\x12\x15\n\rsummer_clocks\x18\x03 \x03(\t\x12\x15\n\rwinter_clocks\x18\x04 \x03(\t\x12\x10\n\x08holidays\x18\x05 \x03(\t\x12\x15\n\rcrypto_clocks\x18\x06 \x03(\t\"x\n\rSettleFunding\x12\x12\n\nis_funding\x18\x01 \x01(\x08\x12\x38\n\x10next_position_id\x18\x02 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12\x19\n\x0bmarket_type\x18\x03 \x01(\tB\x04\xc8\xde\x1f\x01\"\xc5\x02\n\x10PremiumIndexConf\x12\x15\n\rupdate_period\x18\x01 \x01(\x03\x12\x18\n\x10next_update_time\x18\x02 \x01(\x03\x12\x18\n\x10round_start_time\x18\x03 \x01(\x03\x12\x17\n\x0fnext_round_time\x18\x04 \x01(\x03\x12\x13\n\x0bround_index\x18\x05 \x01(\x05\x12\"\n\x14\x63rypto_update_period\x18\x06 \x01(\x03\x42\x04\xc8\xde\x1f\x01\x12%\n\x17\x63rypto_next_update_time\x18\x07 \x01(\x03\x42\x04\xc8\xde\x1f\x01\x12%\n\x17\x63rypto_round_start_time\x18\x08 \x01(\x03\x42\x04\xc8\xde\x1f\x01\x12$\n\x16\x63rypto_next_round_time\x18\t \x01(\x03\x42\x04\xc8\xde\x1f\x01\x12 \n\x12\x63rypto_round_index\x18\n \x01(\x05\x42\x04\xc8\xde\x1f\x01\"\xb3\x01\n\x0cPremiumIndex\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x17\n\x0fround_timestamp\x18\x02 \x01(\x03\x12\x31\n\x05ticks\x18\x03 \x03(\x0b\x32\x1c.fx.dex.v1.PremiumIndex.TickB\x04\xc8\xde\x1f\x00\x1a\x46\n\x04Tick\x12\x32\n\x05value\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\n\n\x02ts\x18\x02 \x01(\x03\"F\n\x13MovingAverageParams\x12\x15\n\rupdate_period\x18\x01 \x01(\x03\x12\x18\n\x10next_update_time\x18\x02 \x01(\x03\"K\n\rMovingAverage\x12:\n\raverage_price\x18\x01 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecB-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.funding_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _PAIRFUNDINGRATE.fields_by_name['funding_rate']._options = None
  _PAIRFUNDINGRATE.fields_by_name['funding_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _FUNDING.fields_by_name['crypto_funding_period']._options = None
  _FUNDING.fields_by_name['crypto_funding_period']._serialized_options = b'\310\336\037\001'
  _FUNDING.fields_by_name['crypto_next_funding_time']._options = None
  _FUNDING.fields_by_name['crypto_next_funding_time']._serialized_options = b'\310\336\037\001'
  _FUNDING.fields_by_name['crypto_funding_times']._options = None
  _FUNDING.fields_by_name['crypto_funding_times']._serialized_options = b'\310\336\037\001'
  _SETTLEFUNDING.fields_by_name['next_position_id']._options = None
  _SETTLEFUNDING.fields_by_name['next_position_id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _SETTLEFUNDING.fields_by_name['market_type']._options = None
  _SETTLEFUNDING.fields_by_name['market_type']._serialized_options = b'\310\336\037\001'
  _PREMIUMINDEXCONF.fields_by_name['crypto_update_period']._options = None
  _PREMIUMINDEXCONF.fields_by_name['crypto_update_period']._serialized_options = b'\310\336\037\001'
  _PREMIUMINDEXCONF.fields_by_name['crypto_next_update_time']._options = None
  _PREMIUMINDEXCONF.fields_by_name['crypto_next_update_time']._serialized_options = b'\310\336\037\001'
  _PREMIUMINDEXCONF.fields_by_name['crypto_round_start_time']._options = None
  _PREMIUMINDEXCONF.fields_by_name['crypto_round_start_time']._serialized_options = b'\310\336\037\001'
  _PREMIUMINDEXCONF.fields_by_name['crypto_next_round_time']._options = None
  _PREMIUMINDEXCONF.fields_by_name['crypto_next_round_time']._serialized_options = b'\310\336\037\001'
  _PREMIUMINDEXCONF.fields_by_name['crypto_round_index']._options = None
  _PREMIUMINDEXCONF.fields_by_name['crypto_round_index']._serialized_options = b'\310\336\037\001'
  _PREMIUMINDEX_TICK.fields_by_name['value']._options = None
  _PREMIUMINDEX_TICK.fields_by_name['value']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _PREMIUMINDEX.fields_by_name['ticks']._options = None
  _PREMIUMINDEX.fields_by_name['ticks']._serialized_options = b'\310\336\037\000'
  _MOVINGAVERAGE.fields_by_name['average_price']._options = None
  _MOVINGAVERAGE.fields_by_name['average_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PAIRFUNDINGRATE']._serialized_start=60
  _globals['_PAIRFUNDINGRATE']._serialized_end=175
  _globals['_FUNDING']._serialized_start=178
  _globals['_FUNDING']._serialized_end=405
  _globals['_FUNDINGTIME']._serialized_start=408
  _globals['_FUNDINGTIME']._serialized_end=550
  _globals['_SETTLEFUNDING']._serialized_start=552
  _globals['_SETTLEFUNDING']._serialized_end=672
  _globals['_PREMIUMINDEXCONF']._serialized_start=675
  _globals['_PREMIUMINDEXCONF']._serialized_end=1000
  _globals['_PREMIUMINDEX']._serialized_start=1003
  _globals['_PREMIUMINDEX']._serialized_end=1182
  _globals['_PREMIUMINDEX_TICK']._serialized_start=1112
  _globals['_PREMIUMINDEX_TICK']._serialized_end=1182
  _globals['_MOVINGAVERAGEPARAMS']._serialized_start=1184
  _globals['_MOVINGAVERAGEPARAMS']._serialized_end=1254
  _globals['_MOVINGAVERAGE']._serialized_start=1256
  _globals['_MOVINGAVERAGE']._serialized_end=1331
# @@protoc_insertion_point(module_scope)
