# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/legacy/gravity/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n fx/legacy/gravity/v1/types.proto\x12\rfx.gravity.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"5\n\x0f\x42ridgeValidator\x12\r\n\x05power\x18\x01 \x01(\x04\x12\x13\n\x0b\x65th_address\x18\x02 \x01(\t\"X\n\x06Valset\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12/\n\x07members\x18\x02 \x03(\x0b\x32\x1e.fx.gravity.v1.BridgeValidator\x12\x0e\n\x06height\x18\x03 \x01(\x04\"T\n\x1fLastObservedEthereumBlockHeight\x12\x17\n\x0f\x66x_block_height\x18\x01 \x01(\x04\x12\x18\n\x10\x65th_block_height\x18\x02 \x01(\x04\",\n\x0c\x45RC20ToDenom\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"^\n\nERC20Token\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"c\n\x0b\x41ttestation\x12\x10\n\x08observed\x18\x01 \x01(\x08\x12\r\n\x05votes\x18\x02 \x03(\t\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12#\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\xb1\x01\n\x0fOutgoingTxBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x02 \x01(\x04\x12\x37\n\x0ctransactions\x18\x03 \x03(\x0b\x32!.fx.gravity.v1.OutgoingTransferTx\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\r\n\x05\x62lock\x18\x05 \x01(\x04\x12\x12\n\nfeeReceive\x18\x06 \x01(\t\"\xa4\x01\n\x12OutgoingTransferTx\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65st_address\x18\x03 \x01(\t\x12.\n\x0b\x65rc20_token\x18\x04 \x01(\x0b\x32\x19.fx.gravity.v1.ERC20Token\x12,\n\terc20_fee\x18\x05 \x01(\x0b\x32\x19.fx.gravity.v1.ERC20Token\"\xc0\x01\n\tBatchFees\x12\x16\n\x0etoken_contract\x18\x01 \x01(\t\x12\x42\n\ntotal_fees\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x11\n\ttotal_txs\x18\x03 \x01(\x04\x12\x44\n\x0ctotal_amount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"f\n\x0bMinBatchFee\x12\x16\n\x0etoken_contract\x18\x01 \x01(\t\x12?\n\x07\x62\x61seFee\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int*\x9e\x01\n\tClaimType\x12\x1a\n\x16\x43LAIM_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43LAIM_TYPE_DEPOSIT\x10\x01\x12\x17\n\x13\x43LAIM_TYPE_WITHDRAW\x10\x02\x12\x1f\n\x1b\x43LAIM_TYPE_ORIGINATED_TOKEN\x10\x03\x12\x1d\n\x19\x43LAIM_TYPE_VALSET_UPDATED\x10\x04\x1a\x04\x88\xa3\x1e\x00\x42.Z,github.com/functionx/fx-core/x/gravity/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.legacy.gravity.v1.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/gravity/types'
  _CLAIMTYPE._options = None
  _CLAIMTYPE._serialized_options = b'\210\243\036\000'
  _ERC20TOKEN.fields_by_name['amount']._options = None
  _ERC20TOKEN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BATCHFEES.fields_by_name['total_fees']._options = None
  _BATCHFEES.fields_by_name['total_fees']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BATCHFEES.fields_by_name['total_amount']._options = None
  _BATCHFEES.fields_by_name['total_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MINBATCHFEE.fields_by_name['baseFee']._options = None
  _MINBATCHFEE.fields_by_name['baseFee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _globals['_CLAIMTYPE']._serialized_start=1221
  _globals['_CLAIMTYPE']._serialized_end=1379
  _globals['_BRIDGEVALIDATOR']._serialized_start=100
  _globals['_BRIDGEVALIDATOR']._serialized_end=153
  _globals['_VALSET']._serialized_start=155
  _globals['_VALSET']._serialized_end=243
  _globals['_LASTOBSERVEDETHEREUMBLOCKHEIGHT']._serialized_start=245
  _globals['_LASTOBSERVEDETHEREUMBLOCKHEIGHT']._serialized_end=329
  _globals['_ERC20TODENOM']._serialized_start=331
  _globals['_ERC20TODENOM']._serialized_end=375
  _globals['_ERC20TOKEN']._serialized_start=377
  _globals['_ERC20TOKEN']._serialized_end=471
  _globals['_ATTESTATION']._serialized_start=473
  _globals['_ATTESTATION']._serialized_end=572
  _globals['_OUTGOINGTXBATCH']._serialized_start=575
  _globals['_OUTGOINGTXBATCH']._serialized_end=752
  _globals['_OUTGOINGTRANSFERTX']._serialized_start=755
  _globals['_OUTGOINGTRANSFERTX']._serialized_end=919
  _globals['_BATCHFEES']._serialized_start=922
  _globals['_BATCHFEES']._serialized_end=1114
  _globals['_MINBATCHFEE']._serialized_start=1116
  _globals['_MINBATCHFEE']._serialized_end=1218
# @@protoc_insertion_point(module_scope)
