# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/position.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x66x/dex/v1/position.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\">\n\x08StoreDec\x12\x32\n\x05value\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"F\n\x11TotalPositionSize\x12\x31\n\x04size\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"8\n\nPositionID\x12*\n\x02id\x18\x01 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\"@\n\x0bPositionIDs\x12\x31\n\x0cposition_ids\x18\x01 \x03(\x0b\x32\x15.fx.dex.v1.PositionIDB\x04\xc8\xde\x1f\x00\"\xe4\x05\n\x08Position\x12*\n\x02id\x18\x01 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12@\n\x05owner\x18\x02 \x01(\x0c\x42\x31\xfa\xde\x1f-github.com/cosmos/cosmos-sdk/types.AccAddress\x12\x0f\n\x07pair_id\x18\x03 \x01(\t\x12*\n\tdirection\x18\x04 \x01(\x0e\x32\x17.fx.dex.v1.PosDirection\x12\x38\n\x0b\x65ntry_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x37\n\nmark_price\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12>\n\x11liquidation_price\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12:\n\rbase_quantity\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x33\n\x06margin\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x10\n\x08leverage\x18\n \x01(\x03\x12;\n\x0eunrealized_pnl\x18\x0b \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x38\n\x0bmargin_rate\x18\x0c \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12;\n\x0einitial_margin\x18\r \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x43\n\x16pending_order_quantity\x18\x0e \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"9\n\tPositions\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x13.fx.dex.v1.PositionB\x04\xc8\xde\x1f\x00*f\n\x0cPosDirection\x12\"\n\x0cPOSITIONBOTH\x10\x00\x1a\x10\x8a\x9d \x0cPOSITIONBOTH\x12\x12\n\x04LONG\x10\x01\x1a\x08\x8a\x9d \x04LONG\x12\x14\n\x05SHORT\x10\x02\x1a\t\x8a\x9d \x05SHORT\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.position_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _POSDIRECTION._options = None
  _POSDIRECTION._serialized_options = b'\210\243\036\000\250\244\036\001'
  _POSDIRECTION.values_by_name["POSITIONBOTH"]._options = None
  _POSDIRECTION.values_by_name["POSITIONBOTH"]._serialized_options = b'\212\235 \014POSITIONBOTH'
  _POSDIRECTION.values_by_name["LONG"]._options = None
  _POSDIRECTION.values_by_name["LONG"]._serialized_options = b'\212\235 \004LONG'
  _POSDIRECTION.values_by_name["SHORT"]._options = None
  _POSDIRECTION.values_by_name["SHORT"]._serialized_options = b'\212\235 \005SHORT'
  _STOREDEC.fields_by_name['value']._options = None
  _STOREDEC.fields_by_name['value']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _TOTALPOSITIONSIZE.fields_by_name['size']._options = None
  _TOTALPOSITIONSIZE.fields_by_name['size']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITIONID.fields_by_name['id']._options = None
  _POSITIONID.fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _POSITIONIDS.fields_by_name['position_ids']._options = None
  _POSITIONIDS.fields_by_name['position_ids']._serialized_options = b'\310\336\037\000'
  _POSITION.fields_by_name['id']._options = None
  _POSITION.fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _POSITION.fields_by_name['owner']._options = None
  _POSITION.fields_by_name['owner']._serialized_options = b'\372\336\037-github.com/cosmos/cosmos-sdk/types.AccAddress'
  _POSITION.fields_by_name['entry_price']._options = None
  _POSITION.fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['mark_price']._options = None
  _POSITION.fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['liquidation_price']._options = None
  _POSITION.fields_by_name['liquidation_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['base_quantity']._options = None
  _POSITION.fields_by_name['base_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['margin']._options = None
  _POSITION.fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['unrealized_pnl']._options = None
  _POSITION.fields_by_name['unrealized_pnl']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['margin_rate']._options = None
  _POSITION.fields_by_name['margin_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['initial_margin']._options = None
  _POSITION.fields_by_name['initial_margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITION.fields_by_name['pending_order_quantity']._options = None
  _POSITION.fields_by_name['pending_order_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _POSITIONS.fields_by_name['positions']._options = None
  _POSITIONS.fields_by_name['positions']._serialized_options = b'\310\336\037\000'
  _globals['_POSDIRECTION']._serialized_start=1123
  _globals['_POSDIRECTION']._serialized_end=1225
  _globals['_STOREDEC']._serialized_start=61
  _globals['_STOREDEC']._serialized_end=123
  _globals['_TOTALPOSITIONSIZE']._serialized_start=125
  _globals['_TOTALPOSITIONSIZE']._serialized_end=195
  _globals['_POSITIONID']._serialized_start=197
  _globals['_POSITIONID']._serialized_end=253
  _globals['_POSITIONIDS']._serialized_start=255
  _globals['_POSITIONIDS']._serialized_end=319
  _globals['_POSITION']._serialized_start=322
  _globals['_POSITION']._serialized_end=1062
  _globals['_POSITIONS']._serialized_start=1064
  _globals['_POSITIONS']._serialized_end=1121
# @@protoc_insertion_point(module_scope)
