# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.crosschain.v1 import tx_pb2 as fx_dot_crosschain_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the state transitions possible within gravity
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BondedOracle = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/BondedOracle',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracle.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracleResponse.FromString,
                )
        self.AddDelegate = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/AddDelegate',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegate.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegateResponse.FromString,
                )
        self.ReDelegate = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/ReDelegate',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegate.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegateResponse.FromString,
                )
        self.EditBridger = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/EditBridger',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridger.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridgerResponse.FromString,
                )
        self.WithdrawReward = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/WithdrawReward',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawReward.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawRewardResponse.FromString,
                )
        self.UnbondedOracle = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/UnbondedOracle',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracle.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracleResponse.FromString,
                )
        self.OracleSetConfirm = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/OracleSetConfirm',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirm.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirmResponse.FromString,
                )
        self.OracleSetUpdateClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/OracleSetUpdateClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaimResponse.FromString,
                )
        self.BridgeTokenClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/BridgeTokenClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaimResponse.FromString,
                )
        self.SendToFxClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/SendToFxClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaimResponse.FromString,
                )
        self.SendToExternal = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/SendToExternal',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternal.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalResponse.FromString,
                )
        self.CancelSendToExternal = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/CancelSendToExternal',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternal.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternalResponse.FromString,
                )
        self.SendToExternalClaim = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/SendToExternalClaim',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaim.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaimResponse.FromString,
                )
        self.RequestBatch = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/RequestBatch',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatch.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatchResponse.FromString,
                )
        self.ConfirmBatch = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/ConfirmBatch',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatch.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatchResponse.FromString,
                )
        self.UpdateParams = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/UpdateParams',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                )
        self.IncreaseBridgeFee = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/IncreaseBridgeFee',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFee.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFeeResponse.FromString,
                )
        self.UpdateChainOracles = channel.unary_unary(
                '/fx.gravity.crosschain.v1.Msg/UpdateChainOracles',
                request_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOracles.SerializeToString,
                response_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOraclesResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the state transitions possible within gravity
    """

    def BondedOracle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddDelegate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReDelegate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditBridger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawReward(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbondedOracle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetConfirm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleSetUpdateClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BridgeTokenClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToFxClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToExternal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelSendToExternal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendToExternalClaim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/crosschain module
        parameters. The authority is hard-coded to the x/gov module account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncreaseBridgeFee(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChainOracles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BondedOracle': grpc.unary_unary_rpc_method_handler(
                    servicer.BondedOracle,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracle.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracleResponse.SerializeToString,
            ),
            'AddDelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDelegate,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegate.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegateResponse.SerializeToString,
            ),
            'ReDelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.ReDelegate,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegate.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegateResponse.SerializeToString,
            ),
            'EditBridger': grpc.unary_unary_rpc_method_handler(
                    servicer.EditBridger,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridger.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridgerResponse.SerializeToString,
            ),
            'WithdrawReward': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawReward,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawReward.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawRewardResponse.SerializeToString,
            ),
            'UnbondedOracle': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbondedOracle,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracle.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracleResponse.SerializeToString,
            ),
            'OracleSetConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetConfirm,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirm.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirmResponse.SerializeToString,
            ),
            'OracleSetUpdateClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleSetUpdateClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaimResponse.SerializeToString,
            ),
            'BridgeTokenClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.BridgeTokenClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaimResponse.SerializeToString,
            ),
            'SendToFxClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToFxClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaimResponse.SerializeToString,
            ),
            'SendToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToExternal,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternal.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalResponse.SerializeToString,
            ),
            'CancelSendToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelSendToExternal,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternal.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternalResponse.SerializeToString,
            ),
            'SendToExternalClaim': grpc.unary_unary_rpc_method_handler(
                    servicer.SendToExternalClaim,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaim.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaimResponse.SerializeToString,
            ),
            'RequestBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestBatch,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatch.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatchResponse.SerializeToString,
            ),
            'ConfirmBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmBatch,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatch.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatchResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'IncreaseBridgeFee': grpc.unary_unary_rpc_method_handler(
                    servicer.IncreaseBridgeFee,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFee.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFeeResponse.SerializeToString,
            ),
            'UpdateChainOracles': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChainOracles,
                    request_deserializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOracles.FromString,
                    response_serializer=fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOraclesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.gravity.crosschain.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the state transitions possible within gravity
    """

    @staticmethod
    def BondedOracle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/BondedOracle',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracle.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBondedOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddDelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/AddDelegate',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegate.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgAddDelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReDelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/ReDelegate',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegate.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgReDelegateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditBridger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/EditBridger',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridger.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgEditBridgerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WithdrawReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/WithdrawReward',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawReward.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgWithdrawRewardResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbondedOracle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/UnbondedOracle',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracle.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUnbondedOracleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/OracleSetConfirm',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirm.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleSetUpdateClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/OracleSetUpdateClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgOracleSetUpdatedClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BridgeTokenClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/BridgeTokenClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgBridgeTokenClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToFxClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/SendToFxClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToFxClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/SendToExternal',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternal.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelSendToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/CancelSendToExternal',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternal.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgCancelSendToExternalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendToExternalClaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/SendToExternalClaim',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaim.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgSendToExternalClaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/RequestBatch',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatch.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgRequestBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/ConfirmBatch',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatch.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgConfirmBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/UpdateParams',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncreaseBridgeFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/IncreaseBridgeFee',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFee.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgIncreaseBridgeFeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateChainOracles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.gravity.crosschain.v1.Msg/UpdateChainOracles',
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOracles.SerializeToString,
            fx_dot_crosschain_dot_v1_dot_tx__pb2.MsgUpdateChainOraclesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
