# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/erc20/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from fxsdk.x.fx.erc20.v1 import erc20_pb2 as fx_dot_erc20_dot_v1_dot_erc20__pb2
from fxsdk.x.fx.erc20.v1 import genesis_pb2 as fx_dot_erc20_dot_v1_dot_genesis__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x66x/erc20/v1/query.proto\x12\x0b\x66x.erc20.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x17\x66x/erc20/v1/erc20.proto\x1a\x19\x66x/erc20/v1/genesis.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\"T\n\x16QueryTokenPairsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x89\x01\n\x17QueryTokenPairsResponse\x12\x31\n\x0btoken_pairs\x18\x01 \x03(\x0b\x32\x16.fx.erc20.v1.TokenPairB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"&\n\x15QueryTokenPairRequest\x12\r\n\x05token\x18\x01 \x01(\t\"J\n\x16QueryTokenPairResponse\x12\x30\n\ntoken_pair\x18\x01 \x01(\x0b\x32\x16.fx.erc20.v1.TokenPairB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"@\n\x13QueryParamsResponse\x12)\n\x06params\x18\x01 \x01(\x0b\x32\x13.fx.erc20.v1.ParamsB\x04\xc8\xde\x1f\x00\")\n\x18QueryDenomAliasesRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\",\n\x19QueryDenomAliasesResponse\x12\x0f\n\x07\x61liases\x18\x01 \x03(\t\"\'\n\x16QueryAliasDenomRequest\x12\r\n\x05\x61lias\x18\x01 \x01(\t\"(\n\x17QueryAliasDenomResponse\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t2\xeb\x04\n\x05Query\x12y\n\nTokenPairs\x12#.fx.erc20.v1.QueryTokenPairsRequest\x1a$.fx.erc20.v1.QueryTokenPairsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/fx/erc20/v1/token_pairs\x12~\n\tTokenPair\x12\".fx.erc20.v1.QueryTokenPairRequest\x1a#.fx.erc20.v1.QueryTokenPairResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /fx/erc20/v1/token_pairs/{token}\x12h\n\x06Params\x12\x1f.fx.erc20.v1.QueryParamsRequest\x1a .fx.erc20.v1.QueryParamsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/fx/erc20/v1/params\x12\x81\x01\n\x0c\x44\x65nomAliases\x12%.fx.erc20.v1.QueryDenomAliasesRequest\x1a&.fx.erc20.v1.QueryDenomAliasesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/fx/erc20/v1/denom/aliases\x12y\n\nAliasDenom\x12#.fx.erc20.v1.QueryAliasDenomRequest\x1a$.fx.erc20.v1.QueryAliasDenomResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/fx/erc20/v1/alias/denomB,Z*github.com/functionx/fx-core/x/erc20/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.erc20.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/functionx/fx-core/x/erc20/types'
  _QUERYTOKENPAIRSRESPONSE.fields_by_name['token_pairs']._options = None
  _QUERYTOKENPAIRSRESPONSE.fields_by_name['token_pairs']._serialized_options = b'\310\336\037\000'
  _QUERYTOKENPAIRRESPONSE.fields_by_name['token_pair']._options = None
  _QUERYTOKENPAIRRESPONSE.fields_by_name['token_pair']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['TokenPairs']._options = None
  _QUERY.methods_by_name['TokenPairs']._serialized_options = b'\202\323\344\223\002\032\022\030/fx/erc20/v1/token_pairs'
  _QUERY.methods_by_name['TokenPair']._options = None
  _QUERY.methods_by_name['TokenPair']._serialized_options = b'\202\323\344\223\002\"\022 /fx/erc20/v1/token_pairs/{token}'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\025\022\023/fx/erc20/v1/params'
  _QUERY.methods_by_name['DenomAliases']._options = None
  _QUERY.methods_by_name['DenomAliases']._serialized_options = b'\202\323\344\223\002\034\022\032/fx/erc20/v1/denom/aliases'
  _QUERY.methods_by_name['AliasDenom']._options = None
  _QUERY.methods_by_name['AliasDenom']._serialized_options = b'\202\323\344\223\002\032\022\030/fx/erc20/v1/alias/denom'
  _globals['_QUERYTOKENPAIRSREQUEST']._serialized_start=188
  _globals['_QUERYTOKENPAIRSREQUEST']._serialized_end=272
  _globals['_QUERYTOKENPAIRSRESPONSE']._serialized_start=275
  _globals['_QUERYTOKENPAIRSRESPONSE']._serialized_end=412
  _globals['_QUERYTOKENPAIRREQUEST']._serialized_start=414
  _globals['_QUERYTOKENPAIRREQUEST']._serialized_end=452
  _globals['_QUERYTOKENPAIRRESPONSE']._serialized_start=454
  _globals['_QUERYTOKENPAIRRESPONSE']._serialized_end=528
  _globals['_QUERYPARAMSREQUEST']._serialized_start=530
  _globals['_QUERYPARAMSREQUEST']._serialized_end=550
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=552
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=616
  _globals['_QUERYDENOMALIASESREQUEST']._serialized_start=618
  _globals['_QUERYDENOMALIASESREQUEST']._serialized_end=659
  _globals['_QUERYDENOMALIASESRESPONSE']._serialized_start=661
  _globals['_QUERYDENOMALIASESRESPONSE']._serialized_end=705
  _globals['_QUERYALIASDENOMREQUEST']._serialized_start=707
  _globals['_QUERYALIASDENOMREQUEST']._serialized_end=746
  _globals['_QUERYALIASDENOMRESPONSE']._serialized_start=748
  _globals['_QUERYALIASDENOMRESPONSE']._serialized_end=788
  _globals['_QUERY']._serialized_start=791
  _globals['_QUERY']._serialized_end=1410
# @@protoc_insertion_point(module_scope)
