# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/erc20/v1/erc20.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x66x/erc20/v1/erc20.proto\x12\x0b\x66x.erc20.v1\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x14gogoproto/gogo.proto\"t\n\tTokenPair\x12\x15\n\rerc20_address\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12*\n\x0e\x63ontract_owner\x18\x04 \x01(\x0e\x32\x12.fx.erc20.v1.Owner:\x04\xe8\xa0\x1f\x01\"w\n\x14RegisterCoinProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x08metadata\x18\x03 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x00\"h\n\x15RegisterERC20Proposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x65rc20address\x18\x03 \x01(\t\x12\x0f\n\x07\x61liases\x18\x04 \x03(\t:\x04\xe8\xa0\x1f\x00\"X\n\x1dToggleTokenConversionProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t:\x04\xe8\xa0\x1f\x01\"b\n\x18UpdateDenomAliasProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12\r\n\x05\x61lias\x18\x04 \x01(\t:\x04\xe8\xa0\x1f\x00*J\n\x05Owner\x12\x15\n\x11OWNER_UNSPECIFIED\x10\x00\x12\x10\n\x0cOWNER_MODULE\x10\x01\x12\x12\n\x0eOWNER_EXTERNAL\x10\x02\x1a\x04\x88\xa3\x1e\x00\x42,Z*github.com/functionx/fx-core/x/erc20/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.erc20.v1.erc20_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/functionx/fx-core/x/erc20/types'
  _OWNER._options = None
  _OWNER._serialized_options = b'\210\243\036\000'
  _TOKENPAIR._options = None
  _TOKENPAIR._serialized_options = b'\350\240\037\001'
  _REGISTERCOINPROPOSAL.fields_by_name['metadata']._options = None
  _REGISTERCOINPROPOSAL.fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _REGISTERCOINPROPOSAL._options = None
  _REGISTERCOINPROPOSAL._serialized_options = b'\350\240\037\000'
  _REGISTERERC20PROPOSAL._options = None
  _REGISTERERC20PROPOSAL._serialized_options = b'\350\240\037\000'
  _TOGGLETOKENCONVERSIONPROPOSAL._options = None
  _TOGGLETOKENCONVERSIONPROPOSAL._serialized_options = b'\350\240\037\001'
  _UPDATEDENOMALIASPROPOSAL._options = None
  _UPDATEDENOMALIASPROPOSAL._serialized_options = b'\350\240\037\000'
  _globals['_OWNER']._serialized_start=629
  _globals['_OWNER']._serialized_end=703
  _globals['_TOKENPAIR']._serialized_start=94
  _globals['_TOKENPAIR']._serialized_end=210
  _globals['_REGISTERCOINPROPOSAL']._serialized_start=212
  _globals['_REGISTERCOINPROPOSAL']._serialized_end=331
  _globals['_REGISTERERC20PROPOSAL']._serialized_start=333
  _globals['_REGISTERERC20PROPOSAL']._serialized_end=437
  _globals['_TOGGLETOKENCONVERSIONPROPOSAL']._serialized_start=439
  _globals['_TOGGLETOKENCONVERSIONPROPOSAL']._serialized_end=527
  _globals['_UPDATEDENOMALIASPROPOSAL']._serialized_start=529
  _globals['_UPDATEDENOMALIASPROPOSAL']._serialized_end=627
# @@protoc_insertion_point(module_scope)
