# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/gov/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x66x/gov/v1/params.proto\x12\tfx.gov.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"\x8f\x04\n\x06Params\x12\x10\n\x08msg_type\x18\x01 \x01(\t\x12M\n\x0bmin_deposit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1d\xc8\xde\x1f\x00\xea\xde\x1f\x15min_deposit,omitempty\x12]\n\x13min_initial_deposit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB%\xc8\xde\x1f\x00\xea\xde\x1f\x1dmin_initial_deposit,omitempty\x12\x36\n\rvoting_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\x12\x32\n\x06quorum\x18\x05 \x01(\tB\"\xea\xde\x1f\x10quorum,omitempty\xd2\xb4-\ncosmos.Dec\x12[\n\x12max_deposit_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xea\xde\x1f\x1cmax_deposit_period,omitempty\x98\xdf\x1f\x01\x12\x38\n\tthreshold\x18\x07 \x01(\tB%\xea\xde\x1f\x13threshold,omitempty\xd2\xb4-\ncosmos.Dec\x12\x42\n\x0eveto_threshold\x18\x08 \x01(\tB*\xea\xde\x1f\x18veto_threshold,omitempty\xd2\xb4-\ncosmos.Dec\"\xac\x01\n\tEGFParams\x12\x61\n\x15\x65gf_deposit_threshold\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\'\xc8\xde\x1f\x00\xea\xde\x1f\x1f\x65gf_deposit_threshold,omitempty\x12<\n\x0b\x63laim_ratio\x18\x02 \x01(\tB\'\xea\xde\x1f\x15\x63laim_ratio,omitempty\xd2\xb4-\ncosmos.DecB*Z(github.com/functionx/fx-core/x/gov/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.gov.v1.params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(github.com/functionx/fx-core/x/gov/types'
  _PARAMS.fields_by_name['min_deposit']._options = None
  _PARAMS.fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\352\336\037\025min_deposit,omitempty'
  _PARAMS.fields_by_name['min_initial_deposit']._options = None
  _PARAMS.fields_by_name['min_initial_deposit']._serialized_options = b'\310\336\037\000\352\336\037\035min_initial_deposit,omitempty'
  _PARAMS.fields_by_name['voting_period']._options = None
  _PARAMS.fields_by_name['voting_period']._serialized_options = b'\230\337\037\001'
  _PARAMS.fields_by_name['quorum']._options = None
  _PARAMS.fields_by_name['quorum']._serialized_options = b'\352\336\037\020quorum,omitempty\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['max_deposit_period']._options = None
  _PARAMS.fields_by_name['max_deposit_period']._serialized_options = b'\352\336\037\034max_deposit_period,omitempty\230\337\037\001'
  _PARAMS.fields_by_name['threshold']._options = None
  _PARAMS.fields_by_name['threshold']._serialized_options = b'\352\336\037\023threshold,omitempty\322\264-\ncosmos.Dec'
  _PARAMS.fields_by_name['veto_threshold']._options = None
  _PARAMS.fields_by_name['veto_threshold']._serialized_options = b'\352\336\037\030veto_threshold,omitempty\322\264-\ncosmos.Dec'
  _EGFPARAMS.fields_by_name['egf_deposit_threshold']._options = None
  _EGFPARAMS.fields_by_name['egf_deposit_threshold']._serialized_options = b'\310\336\037\000\352\336\037\037egf_deposit_threshold,omitempty'
  _EGFPARAMS.fields_by_name['claim_ratio']._options = None
  _EGFPARAMS.fields_by_name['claim_ratio']._serialized_options = b'\352\336\037\025claim_ratio,omitempty\322\264-\ncosmos.Dec'
  _globals['_PARAMS']._serialized_start=151
  _globals['_PARAMS']._serialized_end=678
  _globals['_EGFPARAMS']._serialized_start=681
  _globals['_EGFPARAMS']._serialized_end=853
# @@protoc_insertion_point(module_scope)
