# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.fx.dex.v1 import order_pb2 as fx_dot_dex_dot_v1_dot_order__pb2
from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x66x/dex/v1/tx.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x15\x66x/dex/v1/order.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\xe7\x01\n\x0eMsgCreateOrder\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07pair_id\x18\x02 \x01(\t\x12\'\n\tdirection\x18\x03 \x01(\x0e\x32\x14.fx.dex.v1.Direction\x12\x32\n\x05price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12:\n\rbase_quantity\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x10\n\x08leverage\x18\x06 \x01(\x03:\n\x82\xe7\xb0*\x05owner\"*\n\x16MsgCreateOrderResponse\x12\x10\n\x08order_id\x18\x01 \x01(\t\"=\n\x0eMsgCancelOrder\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t:\n\x82\xe7\xb0*\x05owner\"\x18\n\x16MsgCancelOrderResponse\"\xa4\x01\n\x0cMsgAddMargin\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07pair_id\x18\x02 \x01(\t\x12\x33\n\x0bposition_id\x18\x03 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12\x33\n\x06margin\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec:\n\x82\xe7\xb0*\x05owner\"\x12\n\x10MsgAddMarginResp\"\x8d\x02\n\x10MsgClosePosition\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07pair_id\x18\x02 \x01(\t\x12\x33\n\x0bposition_id\x18\x03 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12\x32\n\x05price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12:\n\rbase_quantity\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x12\n\nfull_close\x18\x06 \x01(\x08\x12\x14\n\x0cmarket_close\x18\x07 \x01(\x08:\n\x82\xe7\xb0*\x05owner\"(\n\x14MsgClosePositionResp\x12\x10\n\x08order_id\x18\x01 \x01(\t\"s\n\x16MsgLiquidationPosition\x12\x12\n\nliquidator\x18\x01 \x01(\t\x12\x34\n\x0cposition_ids\x18\x02 \x03(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint:\x0f\x82\xe7\xb0*\nliquidator\"\x1c\n\x1aMsgLiquidationPositionResp\"\x90\x01\n\x0eMsgFundDexPool\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tdepositor\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tdepositor\"\x14\n\x12MsgFundDexPoolResp2\xdb\x03\n\x03Msg\x12K\n\x0b\x43reateOrder\x12\x19.fx.dex.v1.MsgCreateOrder\x1a!.fx.dex.v1.MsgCreateOrderResponse\x12K\n\x0b\x43\x61ncelOrder\x12\x19.fx.dex.v1.MsgCancelOrder\x1a!.fx.dex.v1.MsgCancelOrderResponse\x12\x41\n\tAddMargin\x12\x17.fx.dex.v1.MsgAddMargin\x1a\x1b.fx.dex.v1.MsgAddMarginResp\x12M\n\rClosePosition\x12\x1b.fx.dex.v1.MsgClosePosition\x1a\x1f.fx.dex.v1.MsgClosePositionResp\x12_\n\x13LiquidationPosition\x12!.fx.dex.v1.MsgLiquidationPosition\x1a%.fx.dex.v1.MsgLiquidationPositionResp\x12G\n\x0b\x46undDexPool\x12\x19.fx.dex.v1.MsgFundDexPool\x1a\x1d.fx.dex.v1.MsgFundDexPoolRespB-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _MSGCREATEORDER.fields_by_name['price']._options = None
  _MSGCREATEORDER.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MSGCREATEORDER.fields_by_name['base_quantity']._options = None
  _MSGCREATEORDER.fields_by_name['base_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MSGCREATEORDER._options = None
  _MSGCREATEORDER._serialized_options = b'\202\347\260*\005owner'
  _MSGCANCELORDER._options = None
  _MSGCANCELORDER._serialized_options = b'\202\347\260*\005owner'
  _MSGADDMARGIN.fields_by_name['position_id']._options = None
  _MSGADDMARGIN.fields_by_name['position_id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _MSGADDMARGIN.fields_by_name['margin']._options = None
  _MSGADDMARGIN.fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MSGADDMARGIN._options = None
  _MSGADDMARGIN._serialized_options = b'\202\347\260*\005owner'
  _MSGCLOSEPOSITION.fields_by_name['position_id']._options = None
  _MSGCLOSEPOSITION.fields_by_name['position_id']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _MSGCLOSEPOSITION.fields_by_name['price']._options = None
  _MSGCLOSEPOSITION.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MSGCLOSEPOSITION.fields_by_name['base_quantity']._options = None
  _MSGCLOSEPOSITION.fields_by_name['base_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MSGCLOSEPOSITION._options = None
  _MSGCLOSEPOSITION._serialized_options = b'\202\347\260*\005owner'
  _MSGLIQUIDATIONPOSITION.fields_by_name['position_ids']._options = None
  _MSGLIQUIDATIONPOSITION.fields_by_name['position_ids']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _MSGLIQUIDATIONPOSITION._options = None
  _MSGLIQUIDATIONPOSITION._serialized_options = b'\202\347\260*\nliquidator'
  _MSGFUNDDEXPOOL.fields_by_name['amount']._options = None
  _MSGFUNDDEXPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGFUNDDEXPOOL._options = None
  _MSGFUNDDEXPOOL._serialized_options = b'\202\347\260*\tdepositor'
  _globals['_MSGCREATEORDER']._serialized_start=136
  _globals['_MSGCREATEORDER']._serialized_end=367
  _globals['_MSGCREATEORDERRESPONSE']._serialized_start=369
  _globals['_MSGCREATEORDERRESPONSE']._serialized_end=411
  _globals['_MSGCANCELORDER']._serialized_start=413
  _globals['_MSGCANCELORDER']._serialized_end=474
  _globals['_MSGCANCELORDERRESPONSE']._serialized_start=476
  _globals['_MSGCANCELORDERRESPONSE']._serialized_end=500
  _globals['_MSGADDMARGIN']._serialized_start=503
  _globals['_MSGADDMARGIN']._serialized_end=667
  _globals['_MSGADDMARGINRESP']._serialized_start=669
  _globals['_MSGADDMARGINRESP']._serialized_end=687
  _globals['_MSGCLOSEPOSITION']._serialized_start=690
  _globals['_MSGCLOSEPOSITION']._serialized_end=959
  _globals['_MSGCLOSEPOSITIONRESP']._serialized_start=961
  _globals['_MSGCLOSEPOSITIONRESP']._serialized_end=1001
  _globals['_MSGLIQUIDATIONPOSITION']._serialized_start=1003
  _globals['_MSGLIQUIDATIONPOSITION']._serialized_end=1118
  _globals['_MSGLIQUIDATIONPOSITIONRESP']._serialized_start=1120
  _globals['_MSGLIQUIDATIONPOSITIONRESP']._serialized_end=1148
  _globals['_MSGFUNDDEXPOOL']._serialized_start=1151
  _globals['_MSGFUNDDEXPOOL']._serialized_end=1295
  _globals['_MSGFUNDDEXPOOLRESP']._serialized_start=1297
  _globals['_MSGFUNDDEXPOOLRESP']._serialized_end=1317
  _globals['_MSG']._serialized_start=1320
  _globals['_MSG']._serialized_end=1795
# @@protoc_insertion_point(module_scope)
