# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from fxsdk.x.fx.dex.v1 import order_pb2 as fx_dot_dex_dot_v1_dot_order__pb2
from fxsdk.x.fx.dex.v1 import match_pb2 as fx_dot_dex_dot_v1_dot_match__pb2
from fxsdk.x.fx.dex.v1 import position_pb2 as fx_dot_dex_dot_v1_dot_position__pb2
from fxsdk.x.fx.dex.v1 import params_pb2 as fx_dot_dex_dot_v1_dot_params__pb2
from fxsdk.x.fx.dex.v1 import funding_pb2 as fx_dot_dex_dot_v1_dot_funding__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66x/dex/v1/query.proto\x12\tfx.dex.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x15\x66x/dex/v1/order.proto\x1a\x15\x66x/dex/v1/match.proto\x1a\x18\x66x/dex/v1/position.proto\x1a\x16\x66x/dex/v1/params.proto\x1a\x17\x66x/dex/v1/funding.proto\x1a\x14gogoproto/gogo.proto\"\x11\n\x0fQueryReserveReq\"7\n\x10QueryReserveResp\x12#\n\x07reserve\x18\x01 \x01(\x0b\x32\x12.fx.dex.v1.Reserve\"\x13\n\x11QueryIsFundingReq\"(\n\x12QueryIsFundingResp\x12\x12\n\nis_funding\x18\x01 \x01(\x08\"\x18\n\x16QueryStoreStatisticReq\"d\n\x17QueryStoreStatisticResp\x12\x17\n\x0fstore_order_num\x18\x01 \x01(\x03\x12\x16\n\x0eorderbook_size\x18\x02 \x01(\x03\x12\x18\n\x10orderbook_length\x18\x03 \x01(\x03\"\x1d\n\nQueryMAReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\"~\n\x0bQueryMAResp\x12:\n\raverage_price\x18\x01 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x33\n\x06price2\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"@\n\x1aQueryMarkAndOraclePriceReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x11\n\tquery_all\x18\x02 \x01(\x08\"R\n\x1bQueryMarkAndOraclePriceResp\x12\x33\n\x06prices\x18\x01 \x03(\x0b\x32\x1d.fx.dex.v1.MarkAndOraclePriceB\x04\xc8\xde\x1f\x00\"\x10\n\x0eQueryParamsReq\":\n\x0fQueryParamsResp\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x11.fx.dex.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x91\x01\n\x12QueryOrdersRequest\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07pair_id\x18\x02 \x01(\t\x12,\n\x04page\x18\x03 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12-\n\x05limit\x18\x04 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\"=\n\x13QueryOrdersResponse\x12&\n\x06orders\x18\x01 \x03(\x0b\x32\x10.fx.dex.v1.OrderB\x04\xc8\xde\x1f\x00\"%\n\x11QueryOrderRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\";\n\x12QueryOrderResponse\x12%\n\x05order\x18\x01 \x01(\x0b\x32\x10.fx.dex.v1.OrderB\x04\xc8\xde\x1f\x00\"$\n\x11QueryOrderbookReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\"j\n\x12QueryOrderbookResp\x12)\n\x04\x41sks\x18\x01 \x03(\x0b\x32\x15.fx.dex.v1.OrderDepthB\x04\xc8\xde\x1f\x00\x12)\n\x04\x42ids\x18\x02 \x03(\x0b\x32\x15.fx.dex.v1.OrderDepthB\x04\xc8\xde\x1f\x00\"\xbc\x01\n\x11QueryPositionsReq\x12\r\n\x05owner\x18\x01 \x01(\t\x12*\n\tdirection\x18\x02 \x01(\x0e\x32\x17.fx.dex.v1.PosDirection\x12\x0f\n\x07pair_id\x18\x03 \x01(\t\x12,\n\x04page\x18\x04 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12-\n\x05limit\x18\x05 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\"B\n\x12QueryPositionsResp\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x13.fx.dex.v1.PositionB\x04\xc8\xde\x1f\x00\"2\n\x10QueryPositionReq\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07pair_id\x18\x02 \x01(\t\"A\n\x11QueryPositionResp\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x13.fx.dex.v1.PositionB\x04\xc8\xde\x1f\x00\"\x11\n\x0fQueryFundingReq\"=\n\x10QueryFundingResp\x12)\n\x07\x66unding\x18\x01 \x01(\x0b\x32\x12.fx.dex.v1.FundingB\x04\xc8\xde\x1f\x00\"4\n\x18QueryPairFundingRatesReq\x12\x18\n\x10last_or_realtime\x18\x01 \x01(\x08\"Y\n\x19QueryPairFundingRatesResp\x12<\n\x12pair_funding_rates\x18\x01 \x03(\x0b\x32\x1a.fx.dex.v1.PairFundingRateB\x04\xc8\xde\x1f\x00\"\x15\n\x13QueryFundingTimeReq\"J\n\x14QueryFundingTimeResp\x12\x32\n\x0c\x66unding_time\x18\x01 \x01(\x0b\x32\x16.fx.dex.v1.FundingTimeB\x04\xc8\xde\x1f\x00\"P\n\tPairPrice\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x32\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"7\n\x11QueryDealPriceReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x11\n\tquery_all\x18\x02 \x01(\x08\"D\n\x12QueryDealPriceResp\x12.\n\npair_price\x18\x01 \x03(\x0b\x32\x14.fx.dex.v1.PairPriceB\x04\xc8\xde\x1f\x00\"<\n\x13QueryMatchResultReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x03\"J\n\x14QueryMatchResultResp\x12\x32\n\x0cmatch_result\x18\x01 \x01(\x0b\x32\x16.fx.dex.v1.MatchResultB\x04\xc8\xde\x1f\x00\"7\n\x11QueryMarkPriceReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x11\n\tquery_all\x18\x02 \x01(\x08\"I\n\x12QueryMarkPriceResp\x12\x33\n\x0fpair_mark_price\x18\x01 \x03(\x0b\x32\x14.fx.dex.v1.PairPriceB\x04\xc8\xde\x1f\x00\"\x99\x01\n\x12MarkAndOraclePrice\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x37\n\nmark_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x39\n\x0coracle_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"\x97\x02\n\x18QueryLiquidationPriceReq\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x10\n\x08leverage\x18\x02 \x01(\x04\x12*\n\tdirection\x18\x03 \x01(\x0e\x32\x17.fx.dex.v1.PosDirection\x12\x38\n\x0b\x65ntry_price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x35\n\x08quantity\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12;\n\x0ewallet_balance\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"[\n\x19QueryLiquidationPriceResp\x12>\n\x11liquidation_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"\x1a\n\x18QueryPremiumIndexConfReq\"Z\n\x19QueryPremiumIndexConfResp\x12=\n\x12premium_index_conf\x18\x01 \x01(\x0b\x32\x1b.fx.dex.v1.PremiumIndexConfB\x04\xc8\xde\x1f\x00\"!\n\x1fQueryNeedToLiquidationPosIdsReq\"g\n\x1fQueryNeedToLiquidatorPosIdsResp\x12\x34\n\x0cposition_ids\x18\x01 \x03(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x16\x63osmossdk.io/math.Uint\x12\x0e\n\x06height\x18\x02 \x01(\x03\"\x17\n\x15QueryAccountNumberReq\"\'\n\x16QueryAccountNumberResp\x12\r\n\x05value\x18\x01 \x01(\x04\x32\xb2\x12\n\x05Query\x12Y\n\x0bQueryParams\x12\x19.fx.dex.v1.QueryParamsReq\x1a\x1a.fx.dex.v1.QueryParamsResp\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/dex/params\x12\x61\n\x0bQueryOrders\x12\x1d.fx.dex.v1.QueryOrdersRequest\x1a\x1e.fx.dex.v1.QueryOrdersResponse\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/dex/orders\x12]\n\nQueryOrder\x12\x1c.fx.dex.v1.QueryOrderRequest\x1a\x1d.fx.dex.v1.QueryOrderResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/dex/order\x12\x65\n\x0eQueryOrderbook\x12\x1c.fx.dex.v1.QueryOrderbookReq\x1a\x1d.fx.dex.v1.QueryOrderbookResp\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/dex/orderbook\x12\x65\n\x0eQueryPositions\x12\x1c.fx.dex.v1.QueryPositionsReq\x1a\x1d.fx.dex.v1.QueryPositionsResp\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/dex/positions\x12\x61\n\rQueryPosition\x12\x1b.fx.dex.v1.QueryPositionReq\x1a\x1c.fx.dex.v1.QueryPositionResp\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/dex/position\x12]\n\x0cQueryFunding\x12\x1a.fx.dex.v1.QueryFundingReq\x1a\x1b.fx.dex.v1.QueryFundingResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/dex/funding\x12~\n\x15QueryPairFundingRates\x12#.fx.dex.v1.QueryPairFundingRatesReq\x1a$.fx.dex.v1.QueryPairFundingRatesResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/dex/funding_rates\x12n\n\x10QueryFundingTime\x12\x1e.fx.dex.v1.QueryFundingTimeReq\x1a\x1f.fx.dex.v1.QueryFundingTimeResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/dex/funding_time\x12\x66\n\x0eQueryDealPrice\x12\x1c.fx.dex.v1.QueryDealPriceReq\x1a\x1d.fx.dex.v1.QueryDealPriceResp\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/dex/deal_price\x12n\n\x10QueryMatchResult\x12\x1e.fx.dex.v1.QueryMatchResultReq\x1a\x1f.fx.dex.v1.QueryMatchResultResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/dex/match_result\x12\x66\n\x0eQueryMarkPrice\x12\x1c.fx.dex.v1.QueryMarkPriceReq\x1a\x1d.fx.dex.v1.QueryMarkPriceResp\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/dex/mark_price\x12\x88\x01\n\x17QueryMarkAndOraclePrice\x12%.fx.dex.v1.QueryMarkAndOraclePriceReq\x1a&.fx.dex.v1.QueryMarkAndOraclePriceResp\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/dex/mark_oracle_price\x12\x82\x01\n\x15QueryLiquidationPrice\x12#.fx.dex.v1.QueryLiquidationPriceReq\x1a$.fx.dex.v1.QueryLiquidationPriceResp\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/dex/liquidation_price\x12`\n\x12QueryMovingAverage\x12\x15.fx.dex.v1.QueryMAReq\x1a\x16.fx.dex.v1.QueryMAResp\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/dex/moving_average\x12z\n\x13QueryStoreStatistic\x12!.fx.dex.v1.QueryStoreStatisticReq\x1a\".fx.dex.v1.QueryStoreStatisticResp\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/dex/store_statistic\x12\x66\n\x0eQueryIsFunding\x12\x1c.fx.dex.v1.QueryIsFundingReq\x1a\x1d.fx.dex.v1.QueryIsFundingResp\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/dex/is_funding\x12\x83\x01\n\x15QueryPremiumIndexConf\x12#.fx.dex.v1.QueryPremiumIndexConfReq\x1a$.fx.dex.v1.QueryPremiumIndexConfResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/dex/premium_index_conf\x12\x98\x01\n\x1cQueryNeedToLiquidationPosIds\x12*.fx.dex.v1.QueryNeedToLiquidationPosIdsReq\x1a*.fx.dex.v1.QueryNeedToLiquidatorPosIdsResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/dex/liquidation_pos_ids\x12v\n\x12QueryAccountNumber\x12 .fx.dex.v1.QueryAccountNumberReq\x1a!.fx.dex.v1.QueryAccountNumberResp\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/dex/account_number\x12]\n\x0cQueryReserve\x12\x1a.fx.dex.v1.QueryReserveReq\x1a\x1b.fx.dex.v1.QueryReserveResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/dex/reserveB-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _QUERYMARESP.fields_by_name['average_price']._options = None
  _QUERYMARESP.fields_by_name['average_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYMARESP.fields_by_name['price2']._options = None
  _QUERYMARESP.fields_by_name['price2']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYMARKANDORACLEPRICERESP.fields_by_name['prices']._options = None
  _QUERYMARKANDORACLEPRICERESP.fields_by_name['prices']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESP.fields_by_name['params']._options = None
  _QUERYPARAMSRESP.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYORDERSREQUEST.fields_by_name['page']._options = None
  _QUERYORDERSREQUEST.fields_by_name['page']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _QUERYORDERSREQUEST.fields_by_name['limit']._options = None
  _QUERYORDERSREQUEST.fields_by_name['limit']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _QUERYORDERSRESPONSE.fields_by_name['orders']._options = None
  _QUERYORDERSRESPONSE.fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _QUERYORDERRESPONSE.fields_by_name['order']._options = None
  _QUERYORDERRESPONSE.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _QUERYORDERBOOKRESP.fields_by_name['Asks']._options = None
  _QUERYORDERBOOKRESP.fields_by_name['Asks']._serialized_options = b'\310\336\037\000'
  _QUERYORDERBOOKRESP.fields_by_name['Bids']._options = None
  _QUERYORDERBOOKRESP.fields_by_name['Bids']._serialized_options = b'\310\336\037\000'
  _QUERYPOSITIONSREQ.fields_by_name['page']._options = None
  _QUERYPOSITIONSREQ.fields_by_name['page']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _QUERYPOSITIONSREQ.fields_by_name['limit']._options = None
  _QUERYPOSITIONSREQ.fields_by_name['limit']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _QUERYPOSITIONSRESP.fields_by_name['positions']._options = None
  _QUERYPOSITIONSRESP.fields_by_name['positions']._serialized_options = b'\310\336\037\000'
  _QUERYPOSITIONRESP.fields_by_name['positions']._options = None
  _QUERYPOSITIONRESP.fields_by_name['positions']._serialized_options = b'\310\336\037\000'
  _QUERYFUNDINGRESP.fields_by_name['funding']._options = None
  _QUERYFUNDINGRESP.fields_by_name['funding']._serialized_options = b'\310\336\037\000'
  _QUERYPAIRFUNDINGRATESRESP.fields_by_name['pair_funding_rates']._options = None
  _QUERYPAIRFUNDINGRATESRESP.fields_by_name['pair_funding_rates']._serialized_options = b'\310\336\037\000'
  _QUERYFUNDINGTIMERESP.fields_by_name['funding_time']._options = None
  _QUERYFUNDINGTIMERESP.fields_by_name['funding_time']._serialized_options = b'\310\336\037\000'
  _PAIRPRICE.fields_by_name['price']._options = None
  _PAIRPRICE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYDEALPRICERESP.fields_by_name['pair_price']._options = None
  _QUERYDEALPRICERESP.fields_by_name['pair_price']._serialized_options = b'\310\336\037\000'
  _QUERYMATCHRESULTRESP.fields_by_name['match_result']._options = None
  _QUERYMATCHRESULTRESP.fields_by_name['match_result']._serialized_options = b'\310\336\037\000'
  _QUERYMARKPRICERESP.fields_by_name['pair_mark_price']._options = None
  _QUERYMARKPRICERESP.fields_by_name['pair_mark_price']._serialized_options = b'\310\336\037\000'
  _MARKANDORACLEPRICE.fields_by_name['mark_price']._options = None
  _MARKANDORACLEPRICE.fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MARKANDORACLEPRICE.fields_by_name['oracle_price']._options = None
  _MARKANDORACLEPRICE.fields_by_name['oracle_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYLIQUIDATIONPRICEREQ.fields_by_name['entry_price']._options = None
  _QUERYLIQUIDATIONPRICEREQ.fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYLIQUIDATIONPRICEREQ.fields_by_name['quantity']._options = None
  _QUERYLIQUIDATIONPRICEREQ.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYLIQUIDATIONPRICEREQ.fields_by_name['wallet_balance']._options = None
  _QUERYLIQUIDATIONPRICEREQ.fields_by_name['wallet_balance']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYLIQUIDATIONPRICERESP.fields_by_name['liquidation_price']._options = None
  _QUERYLIQUIDATIONPRICERESP.fields_by_name['liquidation_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _QUERYPREMIUMINDEXCONFRESP.fields_by_name['premium_index_conf']._options = None
  _QUERYPREMIUMINDEXCONFRESP.fields_by_name['premium_index_conf']._serialized_options = b'\310\336\037\000'
  _QUERYNEEDTOLIQUIDATORPOSIDSRESP.fields_by_name['position_ids']._options = None
  _QUERYNEEDTOLIQUIDATORPOSIDSRESP.fields_by_name['position_ids']._serialized_options = b'\310\336\037\000\332\336\037\026cosmossdk.io/math.Uint'
  _QUERY.methods_by_name['QueryParams']._options = None
  _QUERY.methods_by_name['QueryParams']._serialized_options = b'\202\323\344\223\002\r\022\013/dex/params'
  _QUERY.methods_by_name['QueryOrders']._options = None
  _QUERY.methods_by_name['QueryOrders']._serialized_options = b'\202\323\344\223\002\r\022\013/dex/orders'
  _QUERY.methods_by_name['QueryOrder']._options = None
  _QUERY.methods_by_name['QueryOrder']._serialized_options = b'\202\323\344\223\002\014\022\n/dex/order'
  _QUERY.methods_by_name['QueryOrderbook']._options = None
  _QUERY.methods_by_name['QueryOrderbook']._serialized_options = b'\202\323\344\223\002\020\022\016/dex/orderbook'
  _QUERY.methods_by_name['QueryPositions']._options = None
  _QUERY.methods_by_name['QueryPositions']._serialized_options = b'\202\323\344\223\002\020\022\016/dex/positions'
  _QUERY.methods_by_name['QueryPosition']._options = None
  _QUERY.methods_by_name['QueryPosition']._serialized_options = b'\202\323\344\223\002\017\022\r/dex/position'
  _QUERY.methods_by_name['QueryFunding']._options = None
  _QUERY.methods_by_name['QueryFunding']._serialized_options = b'\202\323\344\223\002\016\022\014/dex/funding'
  _QUERY.methods_by_name['QueryPairFundingRates']._options = None
  _QUERY.methods_by_name['QueryPairFundingRates']._serialized_options = b'\202\323\344\223\002\024\022\022/dex/funding_rates'
  _QUERY.methods_by_name['QueryFundingTime']._options = None
  _QUERY.methods_by_name['QueryFundingTime']._serialized_options = b'\202\323\344\223\002\023\022\021/dex/funding_time'
  _QUERY.methods_by_name['QueryDealPrice']._options = None
  _QUERY.methods_by_name['QueryDealPrice']._serialized_options = b'\202\323\344\223\002\021\022\017/dex/deal_price'
  _QUERY.methods_by_name['QueryMatchResult']._options = None
  _QUERY.methods_by_name['QueryMatchResult']._serialized_options = b'\202\323\344\223\002\023\022\021/dex/match_result'
  _QUERY.methods_by_name['QueryMarkPrice']._options = None
  _QUERY.methods_by_name['QueryMarkPrice']._serialized_options = b'\202\323\344\223\002\021\022\017/dex/mark_price'
  _QUERY.methods_by_name['QueryMarkAndOraclePrice']._options = None
  _QUERY.methods_by_name['QueryMarkAndOraclePrice']._serialized_options = b'\202\323\344\223\002\030\022\026/dex/mark_oracle_price'
  _QUERY.methods_by_name['QueryLiquidationPrice']._options = None
  _QUERY.methods_by_name['QueryLiquidationPrice']._serialized_options = b'\202\323\344\223\002\030\022\026/dex/liquidation_price'
  _QUERY.methods_by_name['QueryMovingAverage']._options = None
  _QUERY.methods_by_name['QueryMovingAverage']._serialized_options = b'\202\323\344\223\002\025\022\023/dex/moving_average'
  _QUERY.methods_by_name['QueryStoreStatistic']._options = None
  _QUERY.methods_by_name['QueryStoreStatistic']._serialized_options = b'\202\323\344\223\002\026\022\024/dex/store_statistic'
  _QUERY.methods_by_name['QueryIsFunding']._options = None
  _QUERY.methods_by_name['QueryIsFunding']._serialized_options = b'\202\323\344\223\002\021\022\017/dex/is_funding'
  _QUERY.methods_by_name['QueryPremiumIndexConf']._options = None
  _QUERY.methods_by_name['QueryPremiumIndexConf']._serialized_options = b'\202\323\344\223\002\031\022\027/dex/premium_index_conf'
  _QUERY.methods_by_name['QueryNeedToLiquidationPosIds']._options = None
  _QUERY.methods_by_name['QueryNeedToLiquidationPosIds']._serialized_options = b'\202\323\344\223\002\032\022\030/dex/liquidation_pos_ids'
  _QUERY.methods_by_name['QueryAccountNumber']._options = None
  _QUERY.methods_by_name['QueryAccountNumber']._serialized_options = b'\202\323\344\223\002\025\022\023/dex/account_number'
  _QUERY.methods_by_name['QueryReserve']._options = None
  _QUERY.methods_by_name['QueryReserve']._serialized_options = b'\202\323\344\223\002\016\022\014/dex/reserve'
  _globals['_QUERYRESERVEREQ']._serialized_start=209
  _globals['_QUERYRESERVEREQ']._serialized_end=226
  _globals['_QUERYRESERVERESP']._serialized_start=228
  _globals['_QUERYRESERVERESP']._serialized_end=283
  _globals['_QUERYISFUNDINGREQ']._serialized_start=285
  _globals['_QUERYISFUNDINGREQ']._serialized_end=304
  _globals['_QUERYISFUNDINGRESP']._serialized_start=306
  _globals['_QUERYISFUNDINGRESP']._serialized_end=346
  _globals['_QUERYSTORESTATISTICREQ']._serialized_start=348
  _globals['_QUERYSTORESTATISTICREQ']._serialized_end=372
  _globals['_QUERYSTORESTATISTICRESP']._serialized_start=374
  _globals['_QUERYSTORESTATISTICRESP']._serialized_end=474
  _globals['_QUERYMAREQ']._serialized_start=476
  _globals['_QUERYMAREQ']._serialized_end=505
  _globals['_QUERYMARESP']._serialized_start=507
  _globals['_QUERYMARESP']._serialized_end=633
  _globals['_QUERYMARKANDORACLEPRICEREQ']._serialized_start=635
  _globals['_QUERYMARKANDORACLEPRICEREQ']._serialized_end=699
  _globals['_QUERYMARKANDORACLEPRICERESP']._serialized_start=701
  _globals['_QUERYMARKANDORACLEPRICERESP']._serialized_end=783
  _globals['_QUERYPARAMSREQ']._serialized_start=785
  _globals['_QUERYPARAMSREQ']._serialized_end=801
  _globals['_QUERYPARAMSRESP']._serialized_start=803
  _globals['_QUERYPARAMSRESP']._serialized_end=861
  _globals['_QUERYORDERSREQUEST']._serialized_start=864
  _globals['_QUERYORDERSREQUEST']._serialized_end=1009
  _globals['_QUERYORDERSRESPONSE']._serialized_start=1011
  _globals['_QUERYORDERSRESPONSE']._serialized_end=1072
  _globals['_QUERYORDERREQUEST']._serialized_start=1074
  _globals['_QUERYORDERREQUEST']._serialized_end=1111
  _globals['_QUERYORDERRESPONSE']._serialized_start=1113
  _globals['_QUERYORDERRESPONSE']._serialized_end=1172
  _globals['_QUERYORDERBOOKREQ']._serialized_start=1174
  _globals['_QUERYORDERBOOKREQ']._serialized_end=1210
  _globals['_QUERYORDERBOOKRESP']._serialized_start=1212
  _globals['_QUERYORDERBOOKRESP']._serialized_end=1318
  _globals['_QUERYPOSITIONSREQ']._serialized_start=1321
  _globals['_QUERYPOSITIONSREQ']._serialized_end=1509
  _globals['_QUERYPOSITIONSRESP']._serialized_start=1511
  _globals['_QUERYPOSITIONSRESP']._serialized_end=1577
  _globals['_QUERYPOSITIONREQ']._serialized_start=1579
  _globals['_QUERYPOSITIONREQ']._serialized_end=1629
  _globals['_QUERYPOSITIONRESP']._serialized_start=1631
  _globals['_QUERYPOSITIONRESP']._serialized_end=1696
  _globals['_QUERYFUNDINGREQ']._serialized_start=1698
  _globals['_QUERYFUNDINGREQ']._serialized_end=1715
  _globals['_QUERYFUNDINGRESP']._serialized_start=1717
  _globals['_QUERYFUNDINGRESP']._serialized_end=1778
  _globals['_QUERYPAIRFUNDINGRATESREQ']._serialized_start=1780
  _globals['_QUERYPAIRFUNDINGRATESREQ']._serialized_end=1832
  _globals['_QUERYPAIRFUNDINGRATESRESP']._serialized_start=1834
  _globals['_QUERYPAIRFUNDINGRATESRESP']._serialized_end=1923
  _globals['_QUERYFUNDINGTIMEREQ']._serialized_start=1925
  _globals['_QUERYFUNDINGTIMEREQ']._serialized_end=1946
  _globals['_QUERYFUNDINGTIMERESP']._serialized_start=1948
  _globals['_QUERYFUNDINGTIMERESP']._serialized_end=2022
  _globals['_PAIRPRICE']._serialized_start=2024
  _globals['_PAIRPRICE']._serialized_end=2104
  _globals['_QUERYDEALPRICEREQ']._serialized_start=2106
  _globals['_QUERYDEALPRICEREQ']._serialized_end=2161
  _globals['_QUERYDEALPRICERESP']._serialized_start=2163
  _globals['_QUERYDEALPRICERESP']._serialized_end=2231
  _globals['_QUERYMATCHRESULTREQ']._serialized_start=2233
  _globals['_QUERYMATCHRESULTREQ']._serialized_end=2293
  _globals['_QUERYMATCHRESULTRESP']._serialized_start=2295
  _globals['_QUERYMATCHRESULTRESP']._serialized_end=2369
  _globals['_QUERYMARKPRICEREQ']._serialized_start=2371
  _globals['_QUERYMARKPRICEREQ']._serialized_end=2426
  _globals['_QUERYMARKPRICERESP']._serialized_start=2428
  _globals['_QUERYMARKPRICERESP']._serialized_end=2501
  _globals['_MARKANDORACLEPRICE']._serialized_start=2504
  _globals['_MARKANDORACLEPRICE']._serialized_end=2657
  _globals['_QUERYLIQUIDATIONPRICEREQ']._serialized_start=2660
  _globals['_QUERYLIQUIDATIONPRICEREQ']._serialized_end=2939
  _globals['_QUERYLIQUIDATIONPRICERESP']._serialized_start=2941
  _globals['_QUERYLIQUIDATIONPRICERESP']._serialized_end=3032
  _globals['_QUERYPREMIUMINDEXCONFREQ']._serialized_start=3034
  _globals['_QUERYPREMIUMINDEXCONFREQ']._serialized_end=3060
  _globals['_QUERYPREMIUMINDEXCONFRESP']._serialized_start=3062
  _globals['_QUERYPREMIUMINDEXCONFRESP']._serialized_end=3152
  _globals['_QUERYNEEDTOLIQUIDATIONPOSIDSREQ']._serialized_start=3154
  _globals['_QUERYNEEDTOLIQUIDATIONPOSIDSREQ']._serialized_end=3187
  _globals['_QUERYNEEDTOLIQUIDATORPOSIDSRESP']._serialized_start=3189
  _globals['_QUERYNEEDTOLIQUIDATORPOSIDSRESP']._serialized_end=3292
  _globals['_QUERYACCOUNTNUMBERREQ']._serialized_start=3294
  _globals['_QUERYACCOUNTNUMBERREQ']._serialized_end=3317
  _globals['_QUERYACCOUNTNUMBERRESP']._serialized_start=3319
  _globals['_QUERYACCOUNTNUMBERRESP']._serialized_end=3358
  _globals['_QUERY']._serialized_start=3361
  _globals['_QUERY']._serialized_end=5715
# @@protoc_insertion_point(module_scope)
