# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fxsdk.x.fx.migrate.v1 import query_pb2 as fx_dot_migrate_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query provides defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MigrateRecord = channel.unary_unary(
                '/fx.migrate.v1.Query/MigrateRecord',
                request_serializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateRecordRequest.SerializeToString,
                response_deserializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateRecordResponse.FromString,
                )
        self.MigrateCheckAccount = channel.unary_unary(
                '/fx.migrate.v1.Query/MigrateCheckAccount',
                request_serializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateCheckAccountRequest.SerializeToString,
                response_deserializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateCheckAccountResponse.FromString,
                )


class QueryServicer(object):
    """Query provides defines the gRPC querier service.
    """

    def MigrateRecord(self, request, context):
        """DenomTrace queries a denomination trace information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MigrateCheckAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MigrateRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.MigrateRecord,
                    request_deserializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateRecordRequest.FromString,
                    response_serializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateRecordResponse.SerializeToString,
            ),
            'MigrateCheckAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.MigrateCheckAccount,
                    request_deserializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateCheckAccountRequest.FromString,
                    response_serializer=fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateCheckAccountResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'fx.migrate.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query provides defines the gRPC querier service.
    """

    @staticmethod
    def MigrateRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.migrate.v1.Query/MigrateRecord',
            fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateRecordRequest.SerializeToString,
            fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateRecordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MigrateCheckAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/fx.migrate.v1.Query/MigrateCheckAccount',
            fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateCheckAccountRequest.SerializeToString,
            fx_dot_migrate_dot_v1_dot_query__pb2.QueryMigrateCheckAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
